package com.dbnt.sims.equip.mapper;

import com.dbnt.sims.equip.model.CellPhone;
import com.dbnt.sims.equip.model.Equip;
import com.dbnt.sims.equip.model.EquipLog;
import com.dbnt.sims.equip.model.UseList;
import com.dbnt.sims.util.ParamMap;

import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface EquipMapper {

	List<ParamMap> selectEquipStatus(Equip equip);

	List<Equip> selectEquipList(Equip equip);

	Integer selectEquipListCnt(Equip equip);

	Equip selectEquipInfo(Equip equip);

	ParamMap selectEduType(Equip equip);

	Equip selectHistoryDetail(Equip equip);

	List<EquipLog> selectEquipLogList(EquipLog equipLog);

	Integer selectEquipLogListCnt(EquipLog equipLog);

	String selectEquipFirstId(Equip equip);

	List<CellPhone> selectCellPhoneList(CellPhone cellPhone);

	Integer selectCellPhoneListCnt(CellPhone cellPhone);

	List<ParamMap> selectOrganList(UseList useList);

	UseList selectUseNoCnt(UseList useList);

	Integer selectLastUseNo(UseList useList);

	List<UseList> selectUseList(UseList useList);

	Integer selectUseListCnt(UseList useList);

	UseList selectUseInfo(UseList useList);




}
